==> ocaml_1.05.orig.tar.gz: ocaml-1.05.orig/typing/printtyp.mli <==
(***********************************************************************)
(*                                                                     *)
(*                           Objective Caml                            *)
(*                                                                     *)
(*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
(*                                                                     *)
(*  Copyright 1996 Institut National de Recherche en Informatique et   *)
(*  Automatique.  Distributed only by permission.                      *)
(*                                                                     *)
(***********************************************************************)

(* $Id: printtyp.mli,v 1.8 1996/09/23 11:33:13 xleroy Exp $ *)

(* Printing functions *)

open Types

val longident: Longident.t -> unit
val ident: Ident.t -> unit
val path: Path.t -> unit
val reset: unit -> unit
val mark_loops: type_expr -> unit
val type_expr: type_expr -> unit
val type_scheme: type_expr -> unit
val value_description: Ident.t -> value_description -> unit
val type_declaration: Ident.t -> type_declaration -> unit
val exception_declaration: Ident.t -> exception_declaration -> unit
val modtype: module_type -> unit
val signature: signature -> unit
val signature_body: bool -> signature -> unit
val modtype_declaration: Ident.t -> modtype_declaration -> unit
val class_type: Ident.t -> class_type -> unit
val type_expansion: type_expr -> type_expr -> unit
val trace: bool -> (unit -> unit) -> (type_expr * type_expr) list -> unit
val unification_error:
        (type_expr * type_expr) list -> (unit -> unit) -> (unit -> unit) ->
        unit

==> ocaml_2.04.orig.tar.gz: ocaml-2.04/typing/printtyp.mli <==
(***********************************************************************)
(*                                                                     *)
(*                           Objective Caml                            *)
(*                                                                     *)
(*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
(*                                                                     *)
(*  Copyright 1996 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the Q Public License version 1.0.               *)
(*                                                                     *)
(***********************************************************************)

(* $Id: printtyp.mli,v 1.12 1999/11/17 18:58:56 xleroy Exp $ *)

(* Printing functions *)

open Types

val longident: Longident.t -> unit
val ident: Ident.t -> unit
val path: Path.t -> unit
val reset: unit -> unit
val mark_loops: type_expr -> unit
val type_expr: type_expr -> unit
val type_scheme: type_expr -> unit
val value_description: Ident.t -> value_description -> unit
val type_declaration: Ident.t -> type_declaration -> unit
val exception_declaration: Ident.t -> exception_declaration -> unit
val modtype: module_type -> unit
val signature: signature -> unit
val signature_body: bool -> signature -> unit
val modtype_declaration: Ident.t -> modtype_declaration -> unit
val class_type: class_type -> unit
val class_declaration: Ident.t -> class_declaration -> unit
val cltype_declaration: Ident.t -> cltype_declaration -> unit
val type_expansion: type_expr -> type_expr -> unit
val trace: bool -> (unit -> unit) -> (type_expr * type_expr) list -> unit
val unification_error:
        bool -> (type_expr * type_expr) list ->
        (unit -> unit) -> (unit -> unit) ->
        unit
